Skip to contents

For each pair of corresponding strings in a and b, applies OR.delim.split() and checks whether any element is shared between a and b.

Usage

OR.delim.intersect(a, b, delimiter = ",")

Arguments

a

String vector, matrix, or data frame.

b

String vector, matrix, or data frame of the same shape as a.

delimiter

String delimiter. Default = ",".

Value

A logical vector or matrix indicating whether a and b share any element.