Skip to contents

For each pair of corresponding strings in a and b, applies OR.delim.split(), takes the union of the delimited elements, removes duplicate elements, sorts elements alphabetically, and rejoins the elements using the same delimiter.

Usage

OR.delim.merge(a, b, delimiter = ",")

Arguments

a

String vector, matrix, or data frame.

b

String vector, matrix, or data frame of the same shape as a.

delimiter

String delimiter. Default = ",".

Value

A string vector or matrix with merged delimited elements.