Skip to contents

For each string in x, applies OR.delim.split() and replaces common cancer treatments with predefined treatment class ("endocrine", "chemotherapy", "immunotherapy", or "targeted") and selected subclass (such as "her2 and "pd1") labels. Multiple labels, together with any unclassified elements, are returned as a delimited string.

Usage

OR.delim.txclass(x, delimiter = ",")

Arguments

x

String vector of delimited treatments.

delimiter

String delimiter. Default = ",".

Value

A string vector of delimited treatment class labels.