Convert mixed format dates to Microsoft Excel serial dates
Source:R/OncReg.Excel.R
OR.mdyY.to.Excel.RdConverts string dates that may be in serial (using the Microsoft Excel offset), "m/d/y" (e.g., "01/31/00"), or "m/d/Y" format (e.g., "01/31/2000") into numeric serial dates. Two-digit years are expanded using a specified century and pivot year.
See also
Other Excelserialdates:
OR.dmyY.to.Excel()