Returns the number of occurrences of the most common value in x.
See also
Other summary:
OR.max(),
OR.mean(),
OR.min(),
OR.mode(),
OR.rowleft(),
OR.rowmax(),
OR.rowmax.threshold(),
OR.rowmin(),
OR.rowmin.threshold(),
OR.sum()
Returns the number of occurrences of the most common value in x.
Other summary:
OR.max(),
OR.mean(),
OR.min(),
OR.mode(),
OR.rowleft(),
OR.rowmax(),
OR.rowmax.threshold(),
OR.rowmin(),
OR.rowmin.threshold(),
OR.sum()