Computes the maximum value of each row in a matrix or data frame, ignoring
NAs. Returns NA if an entire row is missing.
Details
An example use case in survival analysis is determining the date of last follow-up from several dates when the patient was observed.
See also
Other summary:
OR.max(),
OR.mean(),
OR.min(),
OR.mode(),
OR.modefreq(),
OR.rowleft(),
OR.rowmax.threshold(),
OR.rowmin(),
OR.rowmin.threshold(),
OR.sum()