Skip to contents

For each row of a matrix or data frame, returns the maximum value strictly less than a corresponding threshold, ignoring NAs. Returns NA if no values satisfy the condition.

Usage

OR.rowmax.threshold(input, threshold)

Arguments

input

Numeric matrix or data frame.

threshold

Numeric vector of thresholds of length equal to the number of input rows.

Value

Numeric vector of row-wise maxima below a threshold.

See also