Computes the minimum value of each row in a matrix or data frame, ignoring
NAs. Returns NA if an entire row is missing.
Details
An example use case in survival analysis is determining the event date for progression-free survival based on the dates of progression and death.
See also
Other summary:
OR.max(),
OR.mean(),
OR.min(),
OR.mode(),
OR.modefreq(),
OR.rowleft(),
OR.rowmax(),
OR.rowmax.threshold(),
OR.rowmin.threshold(),
OR.sum()