Skip to contents

Computes Ronchetti's robust analogue¹ of the Akaike information criterion² (AICR) for a linear model fitted by Huber M-estimation³. The effective degrees of freedom term is evaluated using the the Moore–Penrose pseudoinverse⁴ for numerical stability under rank deficiency.

Usage

AICR.Huber(X, y, beta, scale, k2 = 1.345)

Arguments

X

numeric design matrix.

y

numeric response vector.

beta

numeric vector of regression coefficients from a Huber M-estimation fit.

scale

scale estimate from a Huber M-estimation fit.

k2

tuning constant for the Huber ψ-function. Default = 1.345.

Value

The AICR value.

References

  1. Ronchetti, E., 1985. Robust model selection in regression. Statistics & Probability Letters, 3(1), pp. 21–23.

  2. Akaike, H., 1974. A new look at the statistical model identification. IEEE Transactions on Automatic Control, 19(6), pp. 716–723.

  3. Huber, P.J., 1973. Robust regression: asymptotics, conjectures and Monte Carlo. The Annals of Statistics, pp. 799–821.

  4. Penrose, R., 1955. A generalized inverse for matrices. In: Mathematical Proceedings of the Cambridge Philosophical Society, 51(3), pp. 406–413. Cambridge: Cambridge University Press.

See also

Other rlm: rlm.Huber()

Examples

y <- c(36.3, 47.9, 47.2, 43.9, 47.6, 49.6, 53.2, 59.3, 63.2, 70.8, 75.9, 88.5,
       97.3, 103.6, 6.1, 120.2, 135.8, 139.4)
x <- as.matrix(1:length(y) - 1)
fit <- rlm.Huber(X = x, y = y)
print(AICR.Huber(x, y, fit$coefficients, fit$s))
#> [1] 73.36053