Road distance between two addresses using Google Routes API
Source:R/OncReg.Google.R
OR.Google.distance.RdReturns the road distance in km between two addresses. To reduce API calls,
addresses are case-insensitive and whitespace-trimmed, empty addresses after
processing return NA early, processed addresses are internally sorted, and
results are memoized.
Details
If no route is found, input addresses are compared via Google Geocoding API;
identical resolved addresses return 0, otherwise return NA.
See also
Other GoogleMapsPlatform:
OR.Google.TSP(),
OR.Google.address()