Detect delimited string elements (case-insensitive and whitespace-trimmed)
Source:R/OncReg.delim.R
OR.delim.contains.RdFor each string in x, applies OR.delim.split() and checks whether any
delimited element matches one or more specified strings.
Arguments
- x
String vector, matrix, or data frame containing delimited strings.
- match
String vector of elements to match.
- delimiter
String delimiter. Default =
",".- partial
Logical. If
TRUE, each delimited element is tested for substring matches against the providedmatchstrings. IfFALSE(default), matches must be exact.
Value
A logical vector or matrix indicating whether each string contains a delimited element matching any of the specified strings.
See also
Other delim:
OR.delim.intersect(),
OR.delim.merge(),
OR.delim.replace(),
OR.delim.split(),
OR.delim.subset(),
OR.delim.table(),
OR.delim.txclass(),
OR.delim.txname()