Check if two delimited strings share any element (case-insensitive and whitespace-trimmed)
Source:R/OncReg.delim.R
OR.delim.intersect.RdFor each pair of corresponding strings in a and b, applies OR.delim.split()
and checks whether any element is shared between a and b.
See also
Other delim:
OR.delim.contains(),
OR.delim.merge(),
OR.delim.replace(),
OR.delim.split(),
OR.delim.subset(),
OR.delim.table(),
OR.delim.txclass(),
OR.delim.txname()