Merge delimited string elements pairwise (case-insensitive and whitespace-trimmed)
Source:R/OncReg.delim.R
OR.delim.merge.RdFor each pair of corresponding strings in a and b, applies OR.delim.split(),
takes the union of the delimited elements, removes duplicate elements, sorts
elements alphabetically, and rejoins the elements using the same delimiter.
See also
Other delim:
OR.delim.contains(),
OR.delim.intersect(),
OR.delim.replace(),
OR.delim.split(),
OR.delim.subset(),
OR.delim.table(),
OR.delim.txclass(),
OR.delim.txname()