Check if one delimited string is a subset of another (case-insensitive and whitespace-trimmed)
Source:R/OncReg.delim.R
OR.delim.subset.RdFor each pair of corresponding strings in a and b, applies OR.delim.split()
and checks whether all elements in b are
contained in a.
See also
Other delim:
OR.delim.contains(),
OR.delim.intersect(),
OR.delim.merge(),
OR.delim.replace(),
OR.delim.split(),
OR.delim.table(),
OR.delim.txclass(),
OR.delim.txname()