Convert mixed format dates to Microsoft Excel serial dates
Source:R/OncReg.Excel.R
OR.dmyY.to.Excel.RdConverts string dates that may be in serial (using the Microsoft Excel offset), "d/m/y" (e.g., "31/01/00"), or "d/m/Y" format (e.g., "31/01/2000") into numeric serial dates. Two-digit years are expanded using a specified century and pivot year.
See also
Other Excelserialdates:
OR.mdyY.to.Excel()