Solves a minimum-cost unbounded covering knapsack problem by brute-force
enumeration to find vial combinations of denominations that achieve at least
target dose with minimum total cost, breaking ties by the smallest number of vials.
Value
A data frame of optimal combinations with columns:
n1, n2, ..., nk: counts per vial denominationsum_n: total number of vialssum_amount: total dosediff_amount: excess over targetsum_cost: total cost
See also
Other dose:
OR.dose.weights()