Returns the leftmost non-missing value in each row of a matrix or data frame.
Returns NA if an entire row is missing.
Details
An example use case is single imputation where column order defines the hierarchy of preference, such as prioritizing tumor grade from the surgical resection specimen and falling back to the core biopsy result if this is missing.
See also
Other summary:
OR.max(),
OR.mean(),
OR.min(),
OR.mode(),
OR.modefreq(),
OR.rowmax(),
OR.rowmax.threshold(),
OR.rowmin(),
OR.rowmin.threshold(),
OR.sum()