Takes treatment timelines in long format (as produced by
OR.txlines.timeline()) and converts them to wide format with one row per
id and one set of start date, regimen, and event date columns per treatment
line.
Value
A data frame in wide format with columns, where k indexes treatment
lines:
- id
Identifier.
- date.startL(k)
Start date of line
k.- regimenL(k)
Regimens in line
k.- date.eventL(k)
Earliest event date (regardless of line label) after the start date of line
k.
See also
Other txlines:
OR.txlines.restart(),
OR.txlines.timeline(),
OR.txlines.truncate()